@@ -2,9 +2,12 @@ from .cloud_storage import connect, change_namespace, download_file
 from .config import get_auth_token, save_auth_token, check_auth, make_auth, check_config, make_config, load_config, check_ssh_connection, get_token
 from .remote_exec import remote_exec
 from . import vars
+from .cc_debug import cc_print
+from tempfile import gettempdir
+from os import mkdir
 
 # CloudComputing version
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 # Author (GitHub username)
 __author__ = "mp1994"
 
@@ -21,4 +24,10 @@ check_config(silent=True)
 c = load_config()
 if not c is None:
     vars.ssh_host = c['SSH']['host']
-    vars.ssh_port = c['SSH']['port']
\ No newline at end of file
+    vars.ssh_port = c['SSH']['port']
+# Temp dir for download caching
+vars.tempdir = gettempdir() + "/cc_cache/"
+try:
+    mkdir(vars.tempdir)
+except FileExistsError:
+    pass
\ No newline at end of file
